"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getClientEnvironment;

// Grab NODE_ENV and CATALOG_* environment variables and prepare them to be
// injected into the application via DefinePlugin in Webpack configuration.
const CATALOG = /^CATALOG_/i;

function getClientEnvironment(publicUrl) {
  const raw = Object.keys(process.env).filter(key => CATALOG.test(key)).reduce((env, key) => {
    env[key] = process.env[key];
    return env;
  }, {
    // Useful for determining whether we’re running in production mode.
    // Most importantly, it switches React into the correct mode.
    NODE_ENV: process.env.NODE_ENV || "development",
    // Useful for resolving the correct path to static assets in `public`.
    // For example, <img src={process.env.PUBLIC_URL + '/img/logo.png'} />.
    // This should only be used as an escape hatch. Normally you would put
    // images into the `src` and `import` them in code to get their paths.
    PUBLIC_URL: publicUrl
  });
  // Stringify all values so we can feed into Webpack DefinePlugin
  const stringified = {
    "process.env": Object.keys(raw).reduce((env, key) => {
      env[key] = JSON.stringify(raw[key]);
      return env;
    }, {})
  };

  return { raw, stringified };
}